#==============================================================================
# package      DE_EPAGES::Forum::API::Constants
# state        public
# description  Constants for the Forum cartridge
#==============================================================================
package DE_EPAGES::Forum::API::Constants;
use base Exporter;

use strict;
our @EXPORT_OK = qw(
    POST_DELAY
    MAX_PREVIEW_BLOGPOSTS
    BLOGPOST_ADDREPLY_THRESHOLD
    FORUM_ADDTHREAD_THRESHOLD
    FORUMPOST_ADDREPLY_THRESHOLD
    GUESTBOOK_ADDTHREAD_THRESHOLD
);

use DE_EPAGES::Core::API::EpagesConfig qw( EpagesConfig );
use DE_EPAGES::Presentation::API::SpamprotectionConfig qw( SpamprotectionConfig );

use constant DEFAULT_POST_DELAY => 15;
#========================================================================================
# global       POST_DELAY | Sets the time in seconds, that the user has to wait to post
#               again. | integer
#========================================================================================
sub POST_DELAY() { ## no critic qw(RequireCommentForExportedFunctions)
    return EpagesConfig()->get( 'DE_EPAGES::Forum', 'PostDelay', DEFAULT_POST_DELAY );
}

#========================================================================================
# function       BLOGPOST_ADDREPLY_THRESHOLD
# state          public
#----------------------------------------------------------------------------------------
# syntax         my $BlogPostValues = BLOGPOST_ADDREPLY_THRESHOLD();
#----------------------------------------------------------------------------------------
# description    Gets formsubmit timeframe configuration from configuration file for 
#                 AddReply changeAction on BlogPost class
#----------------------------------------------------------------------------------------
# return         ref.hash.boolean
#                 <ul>
#                       <li> IsActive   | boolean </>
#                       <li> Min        | Integer </>
#                       <li> Max        | Integer </>
#                 </ul>
#========================================================================================
sub BLOGPOST_ADDREPLY_THRESHOLD() { ## no critic qw(RequireCommentForExportedFunctions)
    return {
        'IsActive'  => SpamprotectionConfig()->get('DE_EPAGES::Forum', 'BlogPost_AddReply_IsActive'),
        'Min'       => SpamprotectionConfig()->get('DE_EPAGES::Forum', 'BlogPost_AddReply_Min'),
        'Max'       => SpamprotectionConfig()->get('DE_EPAGES::Forum', 'BlogPost_AddReply_Max')
    };
}

#========================================================================================
# function       FORUM_ADDTHREAD_THRESHOLD
# state          public
#----------------------------------------------------------------------------------------
# syntax         my $ForumValues = FORUM_ADDTHREAD_THRESHOLD();
#----------------------------------------------------------------------------------------
# description    Gets formsubmit timeframe configuration from configuration file for
#                 AddThread changeAction on Forum class
#----------------------------------------------------------------------------------------
# return         ref.hash.boolean
#                 <ul>
#                       <li> IsActive   | boolean </>
#                       <li> Min        | Integer </>
#                       <li> Max        | Integer </>
#                 </ul>
#========================================================================================
sub FORUM_ADDTHREAD_THRESHOLD() { ## no critic qw(RequireCommentForExportedFunctions)
    return {
        'IsActive'  => SpamprotectionConfig()->get('DE_EPAGES::Forum', 'Forum_AddThread_IsActive'),
        'Min'       => SpamprotectionConfig()->get('DE_EPAGES::Forum', 'Forum_AddThread_Min'),
        'Max'       => SpamprotectionConfig()->get('DE_EPAGES::Forum', 'Forum_AddThread_Max')
    };
}

#========================================================================================
# function       FORUMPOST_ADDREPLY_THRESHOLD
# state          public
#----------------------------------------------------------------------------------------
# syntax         my $ForumPostValues = FORUMPOST_ADDREPLY_THRESHOLD();
#----------------------------------------------------------------------------------------
# description    Gets formsubmit timeframe configuration from configuration file for 
#                 AddReply changeAction on ForumPost class
#----------------------------------------------------------------------------------------
# return         ref.hash.boolean
#                 <ul>
#                       <li> IsActive   | boolean </>
#                       <li> Min        | Integer </>
#                       <li> Max        | Integer </>
#                 </ul>
#========================================================================================
sub FORUMPOST_ADDREPLY_THRESHOLD() { ## no critic qw(RequireCommentForExportedFunctions)
    return {
        'IsActive'  => SpamprotectionConfig()->get('DE_EPAGES::Forum', 'ForumPost_AddReply_IsActive'),
        'Min'       => SpamprotectionConfig()->get('DE_EPAGES::Forum', 'ForumPost_AddReply_Min'),
        'Max'       => SpamprotectionConfig()->get('DE_EPAGES::Forum', 'ForumPost_AddReply_Max')
    };
}

#========================================================================================
# function       GUESTBOOK_ADDTHREAD_THRESHOLD
# state          public
#----------------------------------------------------------------------------------------
# syntax         my $GuestBookValues = GUESTBOOK_ADDTHREAD_THRESHOLD();
#----------------------------------------------------------------------------------------
# description    Gets formsubmit timeframe configuration from configuration file for
#                 AddThread changeAction on GuestBook class
#----------------------------------------------------------------------------------------
# return         ref.hash.boolean
#                 <ul>
#                       <li> IsActive   | boolean </>
#                       <li> Min        | Integer </>
#                       <li> Max        | Integer </>
#                 </ul>
#========================================================================================
sub GUESTBOOK_ADDTHREAD_THRESHOLD() { ## no critic qw(RequireCommentForExportedFunctions)
    return {
        'IsActive'  => SpamprotectionConfig()->get('DE_EPAGES::Forum', 'GuestBook_AddThread_IsActive'),
        'Min'       => SpamprotectionConfig()->get('DE_EPAGES::Forum', 'GuestBook_AddThread_Min'),
        'Max'       => SpamprotectionConfig()->get('DE_EPAGES::Forum', 'GuestBook_AddThread_Max')
    };
}

use constant MAX_PREVIEW_BLOGPOSTS => 10;

1;
