#========================================================================================
# package      DE_EPAGES::Forum::Hooks::BlogPost
# state        public
# description  block display of blogpost comments in json tree
#========================================================================================
package DE_EPAGES::Forum::Hooks::BlogPost;

use strict;
use DE_EPAGES::SEO::API::SEO qw ( AddCategoryImageSEOCheckValues );
use DE_EPAGES::Forum::API::Constants qw( BLOGPOST_ADDREPLY_THRESHOLD );

#========================================================================================
# function     OnJSONChildren
#----------------------------------------------------------------------------------------
# syntax       OnJSONChildren( $hParams );
#----------------------------------------------------------------------------------------
# description  Block display of blog posts comments in json children for content tree.
#----------------------------------------------------------------------------------------
# input        $hParams | objects
#               <ul>
#                   <li>Object - object (only blogposts used) - object
#                   <li>Children - list of child info - ref.array.hash.string
#                   <li>Parameters - servlet parameters - ref.hash
#               </ul> | ref.hash.*
#========================================================================================
sub OnJSONChildren {
    my ($hParams) = @_;
    my $Object = $hParams->{'Object'};
    return unless $Object->instanceOf('BlogPost');

    # Blogpost has no visible children in content tree
    @{$hParams->{'Children'}} = ();

    return;
}

#========================================================================================
# function     OnSEOCheckTests
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnSEOCheckTests( $hParams );
#----------------------------------------------------------------------------------------
# description  Extends/changes values from the SEO check for forum objects
#               (Hook SEOCheckTests)
#----------------------------------------------------------------------------------------
# input        $hParams | objects
#               <ul>
#                   <li>Object - object - object
#                   <li>Shop - shop object - object
#                   <li>LanguageID - language id - integer
#                   <li>Values - values and ratings for SEO check - ref.hash
#               </ul> | ref.hash.*
#========================================================================================
sub OnSEOCheckTests {
    my ($hParams) = @_;

    my $BlogPost = $hParams->{'Object'};
    return unless $BlogPost->instanceOf('BlogPost');

    my $hValues = $hParams->{'Values'};
    my $Shop = $hParams->{'Shop'};

    # do these category test also for forums
    AddCategoryImageSEOCheckValues($BlogPost, $Shop, $hValues);
}

#========================================================================================
# function     OnDoAction
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnDoAction( $hParams );
#----------------------------------------------------------------------------------------
# description  Adds timeframe params to the $hParams input hash as defined in configuration.
#               Hook - UI_OnDoAction_SpamProtection
#               Triggered at DE_EPAGES::Presentation::Servlet::Permission::DoAction
#----------------------------------------------------------------------------------------
# input        $hParams | objects
#               <ul>
#                   <li>ObjectClassPath - String
#                   <li>ActionAlias - String
#                   <li>hThresholds - hash
#               </ul> | ref.hash.*
#========================================================================================
sub OnDoAction {
    my ($hParams) = @_;

    my $hTh = $hParams->{'hThresholds'};
    if (($hParams->{'ObjectClassPath'} eq '/Classes/BlogPost') && ($hParams->{'ActionAlias'} eq 'AddReply')) {
            $hTh->{'hParams'} = BLOGPOST_ADDREPLY_THRESHOLD;
    }
    return;
}
1;
