#========================================================================================
# package      DE_EPAGES::Forum::Hooks::Forum
# state        public
# description  hook handler for forum objects
#========================================================================================
package DE_EPAGES::Forum::Hooks::Forum;

use strict;
use DE_EPAGES::SEO::API::SEO qw ( AddCategoryImageSEOCheckValues );
use DE_EPAGES::Forum::API::Constants qw( FORUM_ADDTHREAD_THRESHOLD );

#========================================================================================
# function     OnSEOCheckTests
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnSEOCheckTests( $hParams );
#----------------------------------------------------------------------------------------
# description  Extends/changes values from the SEO check for forum objects
#               (Hook SEOCheckTests)
#----------------------------------------------------------------------------------------
# input        $hParams | objects
#               <ul>
#                   <li>Object - object - object
#                   <li>Shop - shop object - object
#                   <li>LanguageID - language id - integer
#                   <li>Values - values and ratings for SEO check - ref.hash
#               </ul> | ref.hash.*
#========================================================================================
sub OnSEOCheckTests {
    my ($hParams) = @_;

    my $Article = $hParams->{'Object'};
    return unless $Article->instanceOf('Forum');

    my $hValues = $hParams->{'Values'};
    my $Shop = $hParams->{'Shop'};

    # do these category test also for forums
    AddCategoryImageSEOCheckValues($Article, $Shop, $hValues);
}

#========================================================================================
# function     OnDoAction
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnDoAction( $hParams );
#----------------------------------------------------------------------------------------
# description  Adds timeframe params to the $hParams input hash as defined in configuration.
#               Hook - UI_OnDoAction_SpamProtection
#               Triggered at DE_EPAGES::Presentation::Servlet::Permission::DoAction
#----------------------------------------------------------------------------------------
# input        $hParams | objects
#               <ul>
#                   <li>ObjectClassPath - String
#                   <li>ActionAlias - String
#                   <li>hThresholds - hash
#               </ul> | ref.hash.*
#========================================================================================
sub OnDoAction {
    my ($hParams) = @_;

    my $hTh = $hParams->{'hThresholds'};
    if (($hParams->{'ObjectClassPath'} eq '/Classes/Forum') && ($hParams->{'ActionAlias'} eq 'AddThread')) {
            $hTh->{'hParams'} = FORUM_ADDTHREAD_THRESHOLD();
    }
    return;
}
1;
