#========================================================================================
# nocomments
# package      DE_EPAGES::MolliePayments::API::Constants
# state        private
#----------------------------------------------------------------------------------------
# description  constants for cartridge
#========================================================================================
package DE_EPAGES::MolliePayments::API::Constants;
use base Exporter;

use List::Util qw( max );

use strict;



our @EXPORT_OK = qw (
    INTERNAL_CARTRIDGE_NAME
    SUPPORTED_CURRENCIES
    @SPLIT_GATEWAY_METHODS
    $SPLIT_GATEWAY_METHODS_MAXROWS
    PAYMENT_TYPE_MOLLIE_PAYMENTS
    PAYMENT_METHOD_MOLLIE_PAYMENTS
    LINE_ITEM_PAYMENT_MOLLIE_PAYMENTS
    SUPPORTED_LOCALES
    DEFAULT_LOCALE
    SUPPORTED_ORDER_EMBED
    ORDER_EMBED_PAYMENTS
    SUPPORTED_MOLLIE_PAYMENT_STATUS
    TEMPORARY_MOLLIE_PAYMENT_STATUS
    DEFINITIVE_MOLLIE_PAYMENT_STATUS
    MOLLIE_PAYMENT_STATUS_ERRORS
    PAYMENT_STATUS_PAID
    PAYMENT_STATUS_FAILED
    PAYMENT_STATUS_CANCELED
    PAYMENT_STATUS_EXPIRED
    PAYMENT_STATUS_PENDING
    MOLLIE_ORDER_STATUS_CANCELED
    PROFILES_LIMIT_MOLLIE_PAYMENTS
);

use constant PROFILES_LIMIT_MOLLIE_PAYMENTS => 20;
use constant LINE_ITEM_PAYMENT_MOLLIE_PAYMENTS => 'LineItemPaymentMolliePayments';
use constant PAYMENT_TYPE_MOLLIE_PAYMENTS => 'MolliePayments';
use constant PAYMENT_METHOD_MOLLIE_PAYMENTS => 'PaymentMethodMolliePayments';

use constant ORDER_EMBED_PAYMENTS => 'payments';

use constant SUPPORTED_MOLLIE_PAYMENT_STATUS => [qw(
    open
    pending
    authorized
    paid
    canceled
    expired
    failed
)];

use constant TEMPORARY_MOLLIE_PAYMENT_STATUS => [qw(
    open
    pending
    authorized
)];

use constant DEFINITIVE_MOLLIE_PAYMENT_STATUS => [qw(
    canceled
    paid
    expired
    failed
)];
#

use constant MOLLIE_PAYMENT_STATUS_ERRORS => [qw(
    canceled
    expired
    failed
)];

use constant PAYMENT_STATUS_PAID => 'paid';
use constant PAYMENT_STATUS_FAILED => 'failed';
use constant PAYMENT_STATUS_CANCELED => 'canceled';
use constant PAYMENT_STATUS_EXPIRED => 'expired';
use constant PAYMENT_STATUS_PENDING => 'pending';

use constant MOLLIE_ORDER_STATUS_CANCELED => 'canceled';

# This name is used to load objects from database (DON'T CHANGE!)
use constant INTERNAL_CARTRIDGE_NAME => 'MolliePayments';

# Currencies which are supported by MolliePayments.
use constant SUPPORTED_CURRENCIES => [qw(
    EUR
    GBP
)];

# Order Embed which are supported by MolliePayments.
use constant SUPPORTED_ORDER_EMBED => [qw(
    payments
    shipments
)];

# Fallback Locale in case the one we have is not supported by MolliePayments
use constant DEFAULT_LOCALE => 'en_US';

# Locales that are supported by MolliePayments
use constant SUPPORTED_LOCALES => [qw(
    en_US
    nl_NL
    nl_BE
    fr_FR
    fr_BE
    de_DE
    de_AT
    de_CH
    es_ES
    ca_ES
    pt_PT
    it_IT
    nb_NO
    sv_SE
    fi_FI
    da_DK
    is_IS
    hu_HU
    pl_PL
    lv_LV
    lt_LT
)];

our @CreditCards = (
    {
        'isGroup'  => 0,
        'ID'       => 'creditcard',
        'REAL_SGM' => 'creditcard',
        'Name'     => 'Credit Card',
        'LogoName' => ''
    },
    {
        'isGroup'  => 0,
        'ID'       => 'giftcard',
        'REAL_SGM' => 'giftcard',
        'Name'     => 'Gift Card',
        'LogoName' => ''
    },
    {
        'isGroup'  => 0,
        'ID'       => 'paysafecard',
        'REAL_SGM' => 'paysafecard',
        'Name'     => 'Pay Safe Card',
        'LogoName' => ''
    },
);

my @OnlineBankTransfer = (
    {
        'isGroup'       => 0,
        'ID'            => 'belfius',
        'REAL_SGM'      => 'belfius',
        'Name'          => 'Belfius Direct Net',
        'LogoName'      => ''
    },
    {
        'isGroup'       => 0,
        'ID'            => 'giropay',
        'REAL_SGM'      => 'giropay',
        'Name'          => 'Giropay',
        'LogoName'      => ''
    },
    {
        'isGroup'       => 0,
        'ID'            => 'kbc',
        'REAL_SGM'      => 'kbc',
        'Name'          => 'KBC Online',
        'LogoName'      => ''
    },
    {
        'isGroup'       => 0,
        'ID'            => 'ideal',
        'REAL_SGM'      => 'ideal',
        'Name'          => 'iDEAL',
        'LogoName'      => ''
    },
    {
        'isGroup'       => 0,
        'ID'            => 'sofort',
        'REAL_SGM'      => 'sofort',
        'Name'          => 'Sofort',
        'LogoName'      => '',
    },
    {
        'isGroup'       => 0,
        'ID'            => 'inghomepay',
        'REAL_SGM'      => 'inghomepay',
        'Name'          => 'ING HomePay',
        'LogoName'      => ''
    },
);

my @DirectDebit = (
    {
        'isGroup'       => 0,
        'ID'            => 'directdebit',
        'REAL_SGM'      => 'directdebit',
        'Name'          => 'Direct Debit',
        'LogoName'      => ''
    },
);

my @OfflinePayByInvoice = (
    {
        'isGroup'       => 0,
        'ID'            => 'banktransfer',
        'REAL_SGM'      => 'banktransfer',
        'Name'          => 'Bank transfer',
        'LogoName'      => ''
    },
);

my @OtherPaymentMethods = (
    {
        'isGroup'       => 0,
        'ID'            => 'applepay',
        'REAL_SGM'      => 'applepay',
        'Name'          => 'ApplePay',
        'LogoName'      => ''
    },
    {
        'isGroup'       => 0,
        'ID'            => 'bancontact',
        'REAL_SGM'      => 'bancontact',
        'Name'          => 'Bancontact',
        'LogoName'      => ''
    },
    {
        'isGroup'       => 0,
        'ID'            => 'eps',
        'REAL_SGM'      => 'eps',
        'Name'          => 'EPS',
        'LogoName'      => ''
    },
    {
        'isGroup'       => 0,
        'ID'            => 'mybank',
        'REAL_SGM'      => 'mybank',
        'Name'          => 'MyBank',
        'LogoName'      => ''
    },
    {
        'isGroup'       => 0,
        'ID'            => 'paypal',
        'REAL_SGM'      => 'paypal',
        'Name'          => 'PayPal',
        'LogoName'      => ''
    },
    {
        'isGroup'       => 0,
        'ID'            => 'przelewy24',
        'REAL_SGM'      => 'przelewy24',
        'Name'          => 'Przelewy24',
        'LogoName'      => ''
    },
);

our @KlarnaPayments = (
    {
        'isGroup'  => 0,
        'ID'       => 'klarnapaylater',
        'REAL_SGM' => 'klarnapaylater',
        'Name'     => 'Klarna: Pay later',
        'LogoName' => ''
    },
    {
        'isGroup'  => 0,
        'ID'       => 'klarnasliceit',
        'REAL_SGM' => 'klarnasliceit',
        'Name'     => 'Klarna: Slice it',
        'LogoName' => ''
    }
);

our @SPLIT_GATEWAY_METHODS = (
    {
        'isGroup'  => 1,
        'ID'       => '_01',
        'Name'     => 'Credit Cards',
        'GrpCount' => scalar(@CreditCards)
    },
    @CreditCards,
    {
        'isGroup'  => 1,
        'ID'       => '_02',
        'Name'     => 'Online Bank Transfer',
        'GrpCount' => scalar(@OnlineBankTransfer)
    },
    @OnlineBankTransfer,
    {
        'isGroup'  => 1,
        'ID'       => '_03',
        'Name'     => 'Direct Debit',
        'GrpCount' => scalar(@DirectDebit)
    },
    @DirectDebit,
    {
        'isGroup'  => 1,
        'ID'       => '_04',
        'Name'     => 'Offline - Pay by Invoice',
        'GrpCount' => scalar(@OfflinePayByInvoice)
    },
    @OfflinePayByInvoice,
    {
        'isGroup'  => 1,
        'ID'       => '_05',
        'Name'     => 'Offline - Pay by Invoice',
        'GrpCount' => scalar(@OtherPaymentMethods)
    },
    @OtherPaymentMethods,
    {
        'isGroup'  => 1,
        'ID'       => '_06',
        'Name'     => 'Klarna Payments',
        'GrpCount' => scalar(@KlarnaPayments)
    },
    @KlarnaPayments
);

our $SPLIT_GATEWAY_METHODS_MAXROWS = max(
    scalar(@CreditCards),
    scalar(@OnlineBankTransfer),
    scalar(@DirectDebit),
    scalar(@OfflinePayByInvoice),
    scalar(@OtherPaymentMethods),
    scalar(@KlarnaPayments)
);

1;