#========================================================================================
# package      DE_EPAGES::MolliePayments::API::Requests::OrdersShipments
# state        public
# description  Helper module for generating MolliePayments orders shipments requests to epagesj
#========================================================================================
package DE_EPAGES::MolliePayments::API::Requests::OrdersShipments;
use base DE_EPAGES::MolliePayments::API::Requests::BaseRequest;


use strict;

use constant POST_HTTP_METHOD => 'POST';

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       DE_EPAGES::MolliePayments::API::Requests::Orders->new( );
#----------------------------------------------------------------------------------------
# description  MolliePayments orders requests to epagesj helper constructor
#----------------------------------------------------------------------------------------
# input        $hOrdersData | required data to generate order requests to epagesj | hash.ref
# return       $Object | new object | DE_EPAGES::MolliePayments::API::Requests::Orders
#========================================================================================
sub new {
    my $class = shift;
    my ($hOrdersData) = @_;

    my $self = $class->SUPER::new($hOrdersData);

    return $self;
}


#========================================================================================
# function     getEpagesjRequestSuffixUrlPath
# state        public
#----------------------------------------------------------------------------------------
# syntax       $Url = $OrdersRequest->getEpagesjRequestSuffixUrlPath( $HttpRequestMethod );
#----------------------------------------------------------------------------------------
# description  It returns the orders postfix url path from the epagesj endpoint
#----------------------------------------------------------------------------------------
# input        $HttpRequestMethod | HTTP request method string | string
# return       $Url | orders suffix url path from the epagesj endpoint | string
#========================================================================================
sub getEpagesjRequestSuffixUrlPath {
    my $self = shift;
    my ($HttpRequestMethod) = @_;

    if ($HttpRequestMethod eq POST_HTTP_METHOD) {
        my $LineItemPayment = $self->{'data'}->{'container'}->get('Payment');
        my $MollieOrderId = $LineItemPayment->get('MollieOrderId');

        return '/orders/' . $MollieOrderId . '/shipments';
    }
}

#========================================================================================
# function     getHttpHeaders
# state        public
#----------------------------------------------------------------------------------------
# syntax       $hRequestHeader = $self->getHttpHeaders( $HttpRequestMethod );
#----------------------------------------------------------------------------------------
# description  It returns required headers of the orders request
#----------------------------------------------------------------------------------------
# input        $HttpRequestMethod | HTTP request method string | string
# return       $hRequestHeader | orders request headers hash | hash.ref
#========================================================================================
sub getHttpHeaders {
    my $self = shift;
    my ($HttpRequestMethod) = @_;

    if ($HttpRequestMethod eq POST_HTTP_METHOD) {
        return {
            'X-AccessToken' => $self->{'data'}->{'payment'}->get('AccessToken')
        };
    }
}

#========================================================================================
# function     getPayload
# state        public
#----------------------------------------------------------------------------------------
# syntax       $hPayload = $self->getPayload( $HttpRequestMethod );
#----------------------------------------------------------------------------------------
# description  It returns the body payload of the orders request
#----------------------------------------------------------------------------------------
# input        $HttpRequestMethod | HTTP request method string | string
# return       $hPayload | order request payload hash | hash.ref
#========================================================================================
sub getPayload {
    my $self = shift;
    my ($HttpRequestMethod) = @_;

    if ($HttpRequestMethod eq POST_HTTP_METHOD) {
        my $LineItemPayment = $self->{'data'}->{'container'}->get('Payment');

        $self->{'payload'}->{'testmode'} = $LineItemPayment->get('IsTestTransaction') ? 'true' : 'false';
        $self->{'payload'}->{'lines'} = [];
    }

    return $self->{'payload'};
}



#========================================================================================
# function     handleResponse
# state        public
#----------------------------------------------------------------------------------------
# syntax       $hFilteredResponse = $self->handleResponse($hResponse);
#----------------------------------------------------------------------------------------
# description  It returns the response filtered
#----------------------------------------------------------------------------------------
# input        $hResponse | response hash | hash.ref
# return       $hFilteredResponse | filtered response hash | hash.ref
#========================================================================================
sub handleResponse {
    my $self = shift;
    my ($hResponse) = @_;

    return $hResponse;
}

1;