#==============================================================================
# package      DE_EPAGES::MolliePayments::Hooks::OrderProcess
# state        private
#==============================================================================
package DE_EPAGES::MolliePayments::Hooks::OrderProcess;

use strict;
use DE_EPAGES::MolliePayments::UI::BasketOrder;
use DE_EPAGES::MolliePayments::API::Constants qw (
    LINE_ITEM_PAYMENT_MOLLIE_PAYMENTS
);

#========================================================================================
# function     AfterSaveMultiCheckoutConfirmation
# state        public
#----------------------------------------------------------------------------------------
# syntax       AfterSaveMultiCheckoutConfirmation($hParams);
#----------------------------------------------------------------------------------------
# description  check order payment status and redirect to error or success
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Servlet - servlet - object</li>
#                   <li>BasketOrderProcess - basket order process - object</li>
#               </ul> | ref.hash.*
#========================================================================================
sub AfterSaveMultiCheckoutConfirmation {
    my ($hParams) = @_;

    my $Servlet = $hParams->{'Servlet'};
    my $Basket = $Servlet->object();

    my $LineItemContainer = $Basket->container();
    return unless ( defined($LineItemContainer));

    my $LineItemPayment = $LineItemContainer->get('Payment');
    return unless ( defined($LineItemPayment));
    return unless ( $LineItemPayment->instanceOf(LINE_ITEM_PAYMENT_MOLLIE_PAYMENTS));

    DE_EPAGES::MolliePayments::UI::BasketOrder->ValidateOrderPaymentStatus($Servlet, $LineItemPayment);

    return;
}

1;