#========================================================================================
# package      DE_EPAGES::MolliePayments::t::unit::Requests_OrdersShipments
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for DE_EPAGES::MolliePayments::API::Requests::OrdersShipments
#========================================================================================
package DE_EPAGES::MolliePayments::t::unit::Requests_OrdersShipments;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Test::Mock::MockifyEpagesObject;

use Test::Mockify::Sut;
use Test::More;

use strict;

use constant ACCESS_TOKEN => 'MyAccessToken';

use constant MOLLIE_ORDER_ID => 'my_order_id';

use constant ORDERS_SHIPMENTS_SUFFIX_EPAGESJ_PATH => '/orders/' . MOLLIE_ORDER_ID . '/shipments';

use constant SHOP_NAME => 'MyShopName';


sub test {
    my $self = shift;

    $self->test_OrderShipment_creation();
    $self->test_OrderShipment_provision_for_post_path_and_headers();
    $self->test_OrderShipment_provision_for_shop();
    $self->test_OrderShipment_provision_for_post_payload();

   done_testing();
}

#----------------------------------------------------------------------------------------
# Tests
#----------------------------------------------------------------------------------------
sub test_OrderShipment_creation {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $SUT = $self->_createSUT();

    is( scalar(keys %{$SUT->{'data'}}), 2,
            "$SubTestName - Orders Shipments object gets initialized with some arguments."
    );

    is( scalar(keys %{$SUT->{'payload'}}), 0,
            "$SubTestName - Orders Shipments object gets initialized with an empty payload."
    );
}

#----------------------------------------------------------------------------------------
sub test_OrderShipment_provision_for_post_path_and_headers {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $SUT = $self->_createSUT();
    is(
            $SUT->getEpagesjRequestSuffixUrlPath('POST'),
            ORDERS_SHIPMENTS_SUFFIX_EPAGESJ_PATH,
            "$SubTestName - OrdersShipments object provides epagesj suffix path."
    );

    is_deeply(
            $SUT->getHttpHeaders('POST'),
            { 'X-AccessToken' => ACCESS_TOKEN },
            "$SubTestName - OrdersShipments object provides HTTP headers."
    );
}

#----------------------------------------------------------------------------------------
sub test_OrderShipment_provision_for_shop {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $SUT = $self->_createSUT();
    my $Shop = $SUT->getShop();

    is( $Shop->alias(), SHOP_NAME, "$SubTestName - OrdersShipments object provides shop object.");
}

#----------------------------------------------------------------------------------------
sub test_OrderShipment_provision_for_post_payload {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $SUT = $self->_createSUT();

    is_deeply(
            $SUT->getPayload('POST'),
            { 'testmode' => 'true', 'lines' => [] },
            "$SubTestName - OrdersShipments object provides payload"
    );
}

#----------------------------------------------------------------------------------------
# Helpers
#----------------------------------------------------------------------------------------
sub _createSUT {
    my $self = shift;

    my $hData = {
        'container' => $self->_createLineItemContainer(),
        'payment' => $self->_createPayment()
    };

    my $MockifySut = Test::Mockify::Sut->new('DE_EPAGES::MolliePayments::API::Requests::OrdersShipments', [$hData]);

    return $MockifySut->getMockObject();
}

#----------------------------------------------------------------------------------------
sub _createLineItemContainer {
    my $self = shift;

    my $hAttributes = {
        'Payment' => $self->_createLineItemPayment()
    };
    my $MockifyContainer = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
            'DE_EPAGES::Order::API::Object::LineItemContainer', $hAttributes
    );

    return $MockifyContainer->getMockObject();
}

#----------------------------------------------------------------------------------------
sub _createLineItemPayment {
    my $self = shift;
    
    my $hAttributes = {
        'IsTestTransaction' => 1,
        'MollieOrderId' => MOLLIE_ORDER_ID
    };
    my $MockifyContainer = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
            'DE_EPAGES::MolliePayments::API::Object::LineItemPaymentMolliePayments', $hAttributes
    );

    return $MockifyContainer->getMockObject();
}

#----------------------------------------------------------------------------------------
sub _createPayment {
    my $self = shift;

    my $hAttributes = {
        'AccessToken' => ACCESS_TOKEN,
        'Site' => $self->_createShop()
    };
    my $MockifyPaymentMethod = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
            'DE_EPAGES::MolliePayments::API::Object::PaymentMethodMolliePayments', $hAttributes
    );

    return $MockifyPaymentMethod->getMockObject();
}

sub _createShop {
    my $self = shift;

    my $hAttributes = {
        'Alias' => SHOP_NAME
    };
    my $MockifyPaymentMethod = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
            'DE_EPAGES::Shop::API::Object::Shop', $hAttributes
    );

    return $MockifyPaymentMethod->getMockObject();
}

#========================================================================================
# Main
#========================================================================================

__PACKAGE__->runScript();