#========================================================================================
# package      DE_EPAGES::MolliePayments::t::unit::UI_Shop
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for UI::Provider
#========================================================================================
package DE_EPAGES::MolliePayments::t::unit::UI_Shop;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use DE_EPAGES::Test::Mock::MockifyServlet;
use Test::Exception;
use Test::MockObject::Extends;
use Test::More;
use Test::Mockify;
use Test::Mockify::Verify qw ( WasCalled );
use Test::Mockify::Matcher qw ( String );

use strict;

use constant SHOP_ALIAS => 'MyShop';
use constant LINE_ITEM_PAYMENT_GUID => 'AJBD-IOHH-435-IUGU';
use constant MOLLIE_ID => 'tr_d0b0E3EA3v';
use constant OBJECT_ID => '6541';
use constant DEREFERRER_TOKEN => 'DEREFERRER_TOKEN';
use constant TOKEN_PAYLOAD => sprintf('%s&%s&%s', SHOP_ALIAS, OBJECT_ID, LINE_ITEM_PAYMENT_GUID);

sub test {
    my $self = shift;

    $self->test_MolliePaymentsPaymentWebhook_status_paid();

    done_testing();
}

#----------------------------------------------------------------------------------------
# Tests
#----------------------------------------------------------------------------------------
sub test_MolliePaymentsPaymentWebhook_status_paid {
    my $self        = shift;
    my $SubTestName = ( caller(0) )[3];

    my $hShopAttributes = {
        'Alias' => SHOP_ALIAS
    };

    my $MockedShop = $self->_createShop($hShopAttributes);

    my $hServletParams = {
        'id' => MOLLIE_ID,
        'ObjectID' => OBJECT_ID,
        'LineItemPaymentGUID' => LINE_ITEM_PAYMENT_GUID,
        'DereferrerToken' => DEREFERRER_TOKEN
    };
    my $MockedServlet = $self->_createServlet($MockedShop, $hServletParams);
    my $MockedPaymentStatusService = $self->_createPaymentStatusService();

    my $SUT = $self->_createSUT($MockedPaymentStatusService);

    lives_ok(sub { $SUT->MolliePaymentsPaymentWebhook($MockedServlet);}, $SubTestName . ' - test if MolliePaymentsPaymentWebhook can be called without errors');
    ok(WasCalled($MockedPaymentStatusService, 'handleStatusOnPaymentWebhook'), $SubTestName . ' - Verify that handleStatusOnPaymentWebhook was correctly called');

    return;
}

#----------------------------------------------------------------------------------------
# Helpers
#----------------------------------------------------------------------------------------

sub _createServlet {
    my $self = shift;
    my ($MockedShop, $hServletParams) = @_;

    my $Mockify = DE_EPAGES::Test::Mock::MockifyServlet->new( $MockedShop );

    $Mockify->addParams($hServletParams);
    $Mockify->addMockWithReturnValueAndParameterCheck('writeContentOutput', 1, [{'string' => 'OK'}]);

    return $Mockify->getMockObject();
}

sub _createShop {
    my $self = shift;
    my ($hAttributes) = @_;

    my $Mockify = DE_EPAGES::Test::Mock::MockifyEpagesObject->new(
        'DE_EPAGES::Shop::API::Object::Shop', $hAttributes
    );

    return $Mockify->getMockObject();
}

sub _createSUT {
    my $self = shift;
    my ($PaymentStatusService) = @_;

    my $Mockify = Test::Mockify->new('DE_EPAGES::MolliePayments::UI::Shop');

    $Mockify->mock('_ValidateDereferrerToken')->when(String(DEREFERRER_TOKEN), String(TOKEN_PAYLOAD))->thenReturn(1);
    $Mockify->mock('_createPaymentStatusService')->when()->thenReturn($PaymentStatusService);
    $Mockify->mock('_LogPayment')->whenAny()->thenReturn(1);

    return $Mockify->getMockObject();
}

sub _createPaymentStatusService {
    my $self = shift;

    my $Mockify = Test::Mockify->new('DE_EPAGES::MolliePayments::API::PaymentStatusService');
    $Mockify->mock('handleStatusOnPaymentWebhook')->when(String(LINE_ITEM_PAYMENT_GUID), String(MOLLIE_ID))->thenReturn(1);

    return $Mockify->getMockObject();
}

__PACKAGE__->runScript();
