#========================================================================================
# package      DE_EPAGES::Order::t::unit::LineItemContainerData
# base         DE_EPAGES::Core::API::Test
# state        public
#----------------------------------------------------------------------------------------
# description  Unit test for DE_EPAGES::Order::API::LineItemContainerData
#========================================================================================
package DE_EPAGES::Order::t::unit::LineItemContainerData;
use base DE_EPAGES::Core::API::Test;

use DE_EPAGES::Order::API::LineItemContainerData;
use DE_EPAGES::Test::Mock::MockifyEpagesObject;
use DE_EPAGES::Test::Mock::Mockery;
use DE_EPAGES::Shop::API::Constants qw ( TAX_MODEL_NET );
use Test::More;

use strict;



sub test {
    my $self = shift;

    $self->test_getLineItemContainerData_NormalProduct();
    $self->test_getLineItemContainerData_DownloadableProduct();
    $self->test_getLineItemContainerData_NoLineItemContainer();

    $self->test_getShippingData_NormalProduct();
    $self->test_getShippingData_DownloadableProduct();
    $self->test_getShippingData_NoLineItemContainer();

    $self->test_getSystemPaymentData();
    $self->test_getExternalPaymentData();

    $self->test_getPaymentData_NoLineItemContainer();
    $self->test_getPaymentDataNetShop();


    done_testing();
}


sub test_getLineItemContainerData_NormalProduct {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $IsLineItemContainerIncluded = 1;
    my $IsExternalPayment = 0;
    my $Mockery = $self->_createObjects_NormalProduct($IsLineItemContainerIncluded, $IsExternalPayment);
    my $LineItemContainerData = $Mockery->get('SUT');

    my $LanguageID = '2';
    my $LocaleID = 'en_GB';
    my $IncludeTaxInLineItem = 'false';
    my $hLineItemContainerData = $LineItemContainerData->getLineItemContainerData($LanguageID, $LocaleID, $IncludeTaxInLineItem);

    my $hExpectedLineItemContainerData = $self->_createExpectedLineItemContainerData();
    is_deeply($hLineItemContainerData, $hExpectedLineItemContainerData, "$SubTestName - test if expected LineItemContainer data was returned.");
}

sub test_getLineItemContainerData_DownloadableProduct {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createObjects_DownloadableProduct();
    my $LineItemContainerData = $Mockery->get('SUT');

    my $LanguageID = '2';
    my $LocaleID = 'en_GB';
    my $hLineItemContainerData = $LineItemContainerData->getLineItemContainerData($LanguageID, $LocaleID);

    my $hExpectedLineItemContainerData = $self->_createExpectedLineItemContainerData_DownloadableProduct();
    is_deeply($hLineItemContainerData, $hExpectedLineItemContainerData, "$SubTestName - test if expected LineItemContainer data was returned.");
}

sub test_getLineItemContainerData_NoLineItemContainer {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $IsLineItemContainerIncluded = 0;
    my $IsExternalPayment = 0;
    my $Mockery = $self->_createObjects_NormalProduct($IsLineItemContainerIncluded, $IsExternalPayment);
    my $LineItemContainerData = $Mockery->get('SUT');

    my $LanguageID = '2';
    my $LocaleID = 'en_GB';
    my $hLineItemContainerData = $LineItemContainerData->getLineItemContainerData($LanguageID, $LocaleID);

    is_deeply($hLineItemContainerData, undef, "$SubTestName - test if only undef was returned.");
}

sub test_getShippingData_NormalProduct {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $IsLineItemContainerIncluded = 1;
    my $IsExternalPayment = 0;
    my $Mockery = $self->_createObjects_NormalProduct($IsLineItemContainerIncluded, $IsExternalPayment);
    my $LineItemContainerData = $Mockery->get('SUT');

    my $LanguageID = '2';
    my $LocaleID = 'en_GB';
    my $hShippingData = $LineItemContainerData->getShippingData($LanguageID, $LocaleID);

    my $hExpectedShippingData = $self->_createExpectedShippingData();
    is_deeply($hShippingData, $hExpectedShippingData, "$SubTestName - test if expected shipping data was returned.");
}

sub test_getShippingData_DownloadableProduct {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $Mockery = $self->_createObjects_DownloadableProduct();
    my $LineItemContainerData = $Mockery->get('SUT');

    my $LanguageID = '2';
    my $LocaleID = 'en_GB';
    my $hShippingData = $LineItemContainerData->getShippingData($LanguageID, $LocaleID);

    is_deeply($hShippingData, undef, "$SubTestName - test if expected shipping data was returned.");
}

sub test_getShippingData_NoLineItemContainer {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $IsLineItemContainerIncluded = 0;
    my $IsExternalPayment = 0;
    my $Mockery = $self->_createObjects_NormalProduct($IsLineItemContainerIncluded, $IsExternalPayment);
    my $LineItemContainerData = $Mockery->get('SUT');

    my $LanguageID = '2';
    my $LocaleID = 'en_GB';
    my $hShippingData = $LineItemContainerData->getShippingData($LanguageID, $LocaleID);

    is_deeply($hShippingData, undef, "$SubTestName - test if shipping data is undef if there is no LineItemContainer.");
}

sub test_getSystemPaymentData {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $IsLineItemContainerIncluded = 1;
    my $IsExternalPayment = 0;
    my $Mockery = $self->_createObjects_NormalProduct($IsLineItemContainerIncluded, $IsExternalPayment);
    my $LineItemContainerData = $Mockery->get('SUT');

    my $LanguageID = '2';
    my $LocaleID = 'en_GB';
    my $hPaymentData = $LineItemContainerData->getPaymentData($LanguageID, $LocaleID);

    my $hExpectedSystemPaymentData = $self->_createExpectedSystemPaymentData();
    is_deeply($hPaymentData, $hExpectedSystemPaymentData, "$SubTestName - test if expected payment data was returned.");
}

sub test_getExternalPaymentData {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $IsLineItemContainerIncluded = 1;
    my $IsExternalPayment = 1;
    my $Mockery = $self->_createObjects_NormalProduct($IsLineItemContainerIncluded, $IsExternalPayment);

    my $LineItemContainerData = $Mockery->get('SUT');

    my $LanguageID = '2';
    my $LocaleID = 'en_GB';
    my $hPaymentData = $LineItemContainerData->getPaymentData($LanguageID, $LocaleID);

    my $hExpectedExternalPaymentData = $self->_createExpectedExternalPaymentData();
    is_deeply($hPaymentData, $hExpectedExternalPaymentData, "$SubTestName - test if expected external payment data was returned.");
}

sub test_getPaymentData_NoLineItemContainer {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $IsLineItemContainerIncluded = 0;
    my $IsExternalPayment = 0;
    my $Mockery = $self->_createObjects_NormalProduct($IsLineItemContainerIncluded, $IsExternalPayment);
    my $LineItemContainerData = $Mockery->get('SUT');

    my $LanguageID = '2';
    my $LocaleID = 'en_GB';
    my $hPaymentData = $LineItemContainerData->getPaymentData($LanguageID, $LocaleID);

    is_deeply($hPaymentData, undef, "$SubTestName - test if payment data is undef if there is no LineItemContainer.");
}

sub test_getPaymentDataNetShop {
    my $self = shift;
    my $SubTestName = (caller(0))[3];

    my $IsLineItemContainerIncluded = 1;
    my $IsExternalPayment = 0;
    my $Mockery = $self->_createObjects_NormalProduct($IsLineItemContainerIncluded, $IsExternalPayment);
    my $LineItemContainerData = $Mockery->get('SUT');
    $Mockery->get('LineItemContainer')->set({'TaxModel' => TAX_MODEL_NET});

    my $LanguageID = '2';
    my $LocaleID = 'en_GB';
    my $IncludeTax = 'false';
    my $hPaymentData = $LineItemContainerData->getPaymentData($LanguageID, $LocaleID, $IncludeTax);

    my $hExpectedPaymentData = $self->_createExpectedSystemPaymentData();
    is_deeply($hPaymentData, $hExpectedPaymentData, "$SubTestName - test if expected payment data was returned.");
}

sub _createObjects_NormalProduct {
    my $self = shift;
    my ($IsLineItemContainerIncluded, $IsExternalPayment) = @_;

    $IsLineItemContainerIncluded //= 1;
    my $LineItemPaymentExternalOrInternal = $IsExternalPayment ? 'LineItemExternalPayment' : 'LineItemPayment';

    my $Mockery = DE_EPAGES::Test::Mock::Mockery->new();

    if ($IsLineItemContainerIncluded) {
        $Mockery->register('LineItemContainer', ['Shop', 'LineItemShipping', $LineItemPaymentExternalOrInternal, 'LineItemPaymentDiscount'], sub {
            my ($Shop, $LineItemShipping, $LineItemPayment, $LineItemPaymentDiscount) = @_;
            my $MockifyEpagesObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Order::API::Object::LineItemContainer', {
                'Site' => $Shop,
                'Coupon' => undef,
                'CurrencyID' => 'EUR',
                'TaxModel' => 'GROSS',
                'GrandTotal' => '123.45',
                'TotalBeforeTax' => '56',
                'TotalTax' => '23',
                'LineItemsSubTotal' => '55.2',
                'Shipping' => $LineItemShipping,
                'Payment' => $LineItemPayment,
                'PaymentDiscount' => $LineItemPaymentDiscount,
                'Children' => [],
            });
            return $MockifyEpagesObject->getMockObject();
        });
    } else {
        $Mockery->register('LineItemContainer', [], sub {
            return undef;
        });
    }
    my $DeliveryWeight = 9.78; ## no critic (ProhibitMagicNumbers)
    $Mockery->extend($self->_createCommonMocks($IsLineItemContainerIncluded, $DeliveryWeight));

    return $Mockery->assemble();
}


sub _createObjects_DownloadableProduct {
    my $self = shift;
    my ($IsLineItemContainerIncluded) = @_;
    my $Mockery = DE_EPAGES::Test::Mock::Mockery->new();

    $Mockery->register('LineItemContainer', ['Shop', 'LineItemPayment', 'LineItemPaymentDiscount'], sub {
        my ($Shop, $LineItemPayment, $LineItemPaymentDiscount) = @_;
        my $MockifyEpagesObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Order::API::Object::LineItemContainer', {
            'Site' => $Shop,
            'Coupon' => undef,
            'CurrencyID' => 'EUR',
            'TaxModel' => 'GROSS',
            'GrandTotal' => '123.45',
            'TotalBeforeTax' => '56',
            'TotalTax' => '23',
            'LineItemsSubTotal' => '55.2',
            'Shipping' => undef, # downloadable products have no LineItemShipping!
            'Payment' => $LineItemPayment,
            'PaymentDiscount' => $LineItemPaymentDiscount,
            'Children' => [],
        });
        return $MockifyEpagesObject->getMockObject();
    });

    $Mockery->extend($self->_createCommonMocks($IsLineItemContainerIncluded));

    return $Mockery->assemble();
}

sub _createCommonMocks {
    my $self = shift;
    my ($IsLineItemContainerIncluded, $DeliveryWeight) = @_;

    #  Baskets that were converted to orders don't have a LineItemContainer anymore
    $IsLineItemContainerIncluded = $IsLineItemContainerIncluded // 1;

    my $Mockery = DE_EPAGES::Test::Mock::Mockery->new();

    $Mockery->register('SUT', ['LineItemContainer', 'Formatter', 'LineItemsData'], sub {
        my ($LineItemContainer, $Formatter, $LineItemsData) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Order::API::LineItemContainerData', [$LineItemContainer]);
        $Mockify->addMockWithReturnValueAndParameterCheck('_createFormatter', $Formatter, [{'object'=> 'DE_EPAGES::Shop::API::Object::Shop'}, 'string']);
        $Mockify->addMockWithReturnValueAndParameterCheck('_createLineItemsData', $LineItemsData, []);
        $Mockify->addMockWithReturnValueAndParameterCheck('_calculateShippingTaxes', [{ 'price' => {'amount' => 0.40 } }], [{'object' => 'DE_EPAGES::Order::API::Object::LineItemContainer'}, 'string',{'object' => 'DE_EPAGES::Shop::API::Resource::Formatter'}]);
        $Mockify->addMockWithReturnValueAndParameterCheck('_calculatePaymentTaxes', [{ 'price' => {'amount' => 0.20 } }], [{'object' => 'DE_EPAGES::Order::API::Object::LineItemContainer'}, 'string',{'object' => 'DE_EPAGES::Shop::API::Resource::Formatter'}]);
        return $Mockify->getMockObject();
    });

    $Mockery->register('Shop', [], sub {
        my $MockifyEpagesObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Shop::API::Object::Shop', {});
        $MockifyEpagesObject->addMockWithReturnValueAndParameterCheck('siteLocale', 'en_GB', [{'string' => 'en_GB'}]);
        return $MockifyEpagesObject->getMockObject();
    });

    $Mockery->register('Formatter', ['Shop'], sub {
        my ($Shop) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Shop::API::Resource::Formatter', [$Shop, 'en_GB']);
        $Mockify->addMock('quantity', sub {
            my $MockedSelf = shift;
            my ($Quantity, $Unit) = @_;
            return $Quantity;
        });
        $Mockify->addMock('price', sub {
            my $MockedSelf = shift;
            my ($Price, $Currency, $TaxModel) = @_;
            return $Price;
        });
        return $Mockify->getMockObject();
    });

    $Mockery->register('LineItemShipping', ['ShippingMethod'], sub {
        my ($ShippingMethod) = @_;
        my $MockifyEpagesObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Order::API::Object::LineItemShipping', {
            'LineItemPrice' => 2.40,
            'ShippingMethod' => $ShippingMethod,
        });
        return $MockifyEpagesObject->getMockObject();
    });

    $Mockery->register('LineItemsData', ['ShippingMethod'], sub {
        my ($ShippingMethod) = @_;
        my $Mockify = DE_EPAGES::Test::Mock::Mockify->new('DE_EPAGES::Order::API::LineItemsData', []);
        $Mockify->addMockWithReturnValueAndParameterCheck('getLineItems', $self->_getLineItemsData($DeliveryWeight), ['object', 'object', 'string', 'string']);
        return $Mockify->getMockObject();
    });

    $Mockery->register('LineItemPayment', ['LineItemPaymentClass', 'PaymentMethod'], sub {
        my ($LineItemPaymentClass, $PaymentMethod) = @_;
        my $MockifyEpagesObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Order::API::Object::LineItemPayment', {
            'instanceOf' => 'LineItemPayment',
            'LineItemPrice' => 0,
            'PaymentMethod' => $PaymentMethod,
            'PaymentErrorCode' => 'CANCELED',
        });
        $MockifyEpagesObject->addMockWithReturnValue('class', $LineItemPaymentClass);
        #$MockifyEpagesObject->addMockWithReturnValue('getDisplayTransID', 'TestTransactionId');
        return $MockifyEpagesObject->getMockObject();
    });

    $Mockery->register('LineItemExternalPayment', ['LineItemPaymentClass', 'PaymentMethod'], sub {
        my ($LineItemPaymentClass, $PaymentMethod) = @_;
        my $MockifyEpagesObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::ExternalPayment::API::Object::LineItemPaymentExternal', {
            'instanceOf' => 'LineItemPaymentExternal',
            'LineItemPrice' => 0,
            'PaymentMethod' => $PaymentMethod,
            'PaymentErrorCode' => 'CANCELED',
        });
        $MockifyEpagesObject->addMockWithReturnValue('class', $LineItemPaymentClass);
        $MockifyEpagesObject->addMockWithReturnValue('getDisplayTransID', 'TestTransactionId');
        return $MockifyEpagesObject->getMockObject();
    });

    $Mockery->register('LineItemPaymentDiscount', [], sub {
        my $MockifyEpagesObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Order::API::Object::LineItemPaymentDiscount', {
            'LineItemPrice' => 3.20,
        });
        return $MockifyEpagesObject->getMockObject();
    });

    $Mockery->register('LineItemPaymentClass', [], sub {
        my $MockifyEpagesObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Object::API::Object::Class', {});
        $MockifyEpagesObject->addMockWithReturnValueAndParameterCheck('existsAttribute', 1, [{'string' => 'PaymentErrorCode'}]);
        return $MockifyEpagesObject->getMockObject();
    });

    $Mockery->register('OrderUnit', [], sub {
        my $MockifyEpagesObject =
            DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Object::API::Object::UnitOfMeasurement', {});
        return $MockifyEpagesObject->getMockObject();
    });

    $Mockery->register('ShippingMethod', [], sub {
        my $MockifyEpagesObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Shipping::API::Object::ShippingMethod', {
            'GUID' => '6235-43324',
            'NameOrAlias' => 'TestShipping',
        });
        return $MockifyEpagesObject->getMockObject();
    });

    $Mockery->register('TaxClass', [], sub {
        my $MockifyEpagesObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Tax::API::Object::TaxClass', {
            'Name' => 'TaxClassName',
        });
        return $MockifyEpagesObject->getMockObject();
    });

    $Mockery->register('PaymentMethod', [], sub {
        my $MockifyEpagesObject = DE_EPAGES::Test::Mock::MockifyEpagesObject->new('DE_EPAGES::Payment::API::Object::PaymentMethod', {
            'GUID' => '7695-5473452',
            'NameOrAlias' => 'TestPayment'
        });
        $MockifyEpagesObject->addMockWithReturnValueAndParameterCheck('getProviderName', 'TestExternalProviderName', [{'string' => '2'}]);
        return $MockifyEpagesObject->getMockObject();
    });

    return $Mockery;
}

sub _getLineItemsData {
    my $self = shift;
    my ($DeliveryWeight) = @_;
    return [
          {
            'images' => [
                  {
                    'url' => 'http://image.baseurl.test.org/web/path/hotdeal',
                    'classifier' => 'HotDeal'
                  },{
                    'url' => 'http://image.baseurl.test.org/web/path/large',
                    'classifier' => 'Large'
                  },{
                    'url' => 'http://image.baseurl.test.org/web/path/medium',
                    'classifier' => 'Medium'
                  },{
                    'url' => 'http://image.baseurl.test.org/web/path/small',
                    'classifier' => 'Small'
                  },{
                    'url' => 'http://image.baseurl.test.org/web/path/thumbnail',
                    'classifier' => 'Thumbnail'
                  }
                ],
            'sku' => 'abc_12345346',
            'quantity' => 2,
            'name' => 'Product 1',
            'lineItemPrice' => '32.99',
            'productId' => '245345-32534-324234',
            'lineItemId' => '123-35-56562-324352',
            'singleItemPrice' => '32.99',
            'essentialFeatures' => 'test product',
            'taxClass' => {
                'name' => 'TaxClassName',
                'percentage' => 19
            },
            'deliveryWeight' => $DeliveryWeight,
            'links' => [
                 {
                   'rel' => 'product',
                   'href' => 'http://baseurl.test.org/api/products/245345-32534-324234'
                 }
               ]
          }
        ];
}

sub _createExpectedLineItemContainerData {
    return {
      'grandTotal' => '123.45',
      'couponLineItem' => undef,
      'productLineItems' => [
          {
            'images' => [
                  {
                    'url' => 'http://image.baseurl.test.org/web/path/hotdeal',
                    'classifier' => 'HotDeal'
                  },{
                    'url' => 'http://image.baseurl.test.org/web/path/large',
                    'classifier' => 'Large'
                  },{
                    'url' => 'http://image.baseurl.test.org/web/path/medium',
                    'classifier' => 'Medium'
                  },{
                    'url' => 'http://image.baseurl.test.org/web/path/small',
                    'classifier' => 'Small'
                  },{
                    'url' => 'http://image.baseurl.test.org/web/path/thumbnail',
                    'classifier' => 'Thumbnail'
                  },
                ],
            'sku' => 'abc_12345346',
            'quantity' => 2,
            'name' => 'Product 1',
            'lineItemPrice' => '32.99',
            'productId' => '245345-32534-324234',
            'lineItemId' => '123-35-56562-324352',
            'singleItemPrice' => '32.99',
            'essentialFeatures' => 'test product',
            'taxClass' => {
                'name' => 'TaxClassName',
                'percentage' => 19
            },
            'deliveryWeight' => '9.78',
            'links' => [
                 {
                   'rel' => 'product',
                   'href' => 'http://baseurl.test.org/api/products/245345-32534-324234'
                 }
               ]
          }
        ],
      'otherLineItems' => [],
      'totalBeforeTax' => '56',
      'totalTax' => '23',
      'lineItemsSubTotal' => '55.2',
      'shippingPrice' => '2.4',
    };
}

sub _createExpectedLineItemContainerData_DownloadableProduct {
    return {
      'grandTotal' => '123.45',
      'couponLineItem' => undef,
      'productLineItems' => [
          {
            'images' => [
                  {
                    'url' => 'http://image.baseurl.test.org/web/path/hotdeal',
                    'classifier' => 'HotDeal'
                  },{
                    'url' => 'http://image.baseurl.test.org/web/path/large',
                    'classifier' => 'Large'
                  },{
                    'url' => 'http://image.baseurl.test.org/web/path/medium',
                    'classifier' => 'Medium'
                  },{
                    'url' => 'http://image.baseurl.test.org/web/path/small',
                    'classifier' => 'Small'
                  },{
                    'url' => 'http://image.baseurl.test.org/web/path/thumbnail',
                    'classifier' => 'Thumbnail'
                  }
                ],
            'sku' => 'abc_12345346',
            'quantity' => 2,
            'name' => 'Product 1',
            'lineItemPrice' => '32.99',
            'productId' => '245345-32534-324234',
            'lineItemId' => '123-35-56562-324352',
            'singleItemPrice' => '32.99',
            'essentialFeatures' => 'test product',
            'taxClass' => {
                'name' => 'TaxClassName',
                'percentage' => 19
            },
            'deliveryWeight' => undef,
            'links' => [
                 {
                   'rel' => 'product',
                   'href' => 'http://baseurl.test.org/api/products/245345-32534-324234'
                 }
               ]
          }
        ],
      'otherLineItems' => [],
      'totalBeforeTax' => '56',
      'totalTax' => '23',
      'lineItemsSubTotal' => '55.2',
      'shippingPrice' => '0'
    };
}

sub _createExpectedShippingData {
    return {
        'shippingMethod' => {
            'name' => 'TestShipping',
            'id' => '6235-43324'
        },
        'price' => 2.4,
        'taxes' => [{ 'price' => {'amount' => 0.40 } }],
    };
}

sub _createExpectedSystemPaymentData {
    return {
        'paymentMethod' => {
            'name' => 'TestPayment',
            'id' => '7695-5473452',
            'providerName' => undef,
            'additionalData' => undef
        },
        'transactionId' => undef,
        'price' => 3.2,
        'status' => 'CANCELED',
        'taxes' => [{ 'price' => {'amount' => 0.20 } }],
    };
}

sub _createExpectedExternalPaymentData {
    return {
        'paymentMethod' => {
            'name' => 'TestPayment',
            'id' => '7695-5473452',
            'providerName' => 'TestExternalProviderName',
            'additionalData' => undef
        },
        'transactionId' => 'TestTransactionId',
        'price' => 3.2,
        'status' => 'CANCELED',
        'taxes' => [{ 'price' => {'amount' => 0.20 } }],
    };
}


__PACKAGE__->runScript();