#========================================================================================
# package      DE_EPAGES::PayPalPlus::API::Object::LineItemPaymentPayPalPlus
# state        public
# base         DE_EPAGES::ExternalPayment::API::Object::LineItemPaymentExternal
#----------------------------------------------------------------------------------------
# description  object interface for LineItemPaymentPayPalPlus.
#========================================================================================
package DE_EPAGES::PayPalPlus::API::Object::LineItemPaymentPayPalPlus;
use base DE_EPAGES::ExternalPayment::API::Object::LineItemPaymentExternal;

use DE_EPAGES::Core::API::PerlTools qw ( isValid );
use DE_EPAGES::Trigger::API::Trigger qw ( TriggerHook );
use DE_EPAGES::XML::API::DateTimeFormatXML;

use strict;


#========================================================================================
# function     className
# state        public
#----------------------------------------------------------------------------------------
# syntax       $ClassName = $LineItemPaymentPayPalPlus->className;
#----------------------------------------------------------------------------------------
# description  Returns the class name, used for DAL access.
#----------------------------------------------------------------------------------------
# return       $ClassName | class name | String
#========================================================================================
sub className {
    return 'LineItemPaymentPayPalPlus';
}

#========================================================================================
# function     insert
# state        private
#----------------------------------------------------------------------------------------
# syntax       $LineItemPaymentPayPalPlus = DE_EPAGES::PayPalPlus::API::Object::LineItemPaymentPayPalPlus->insert($hInfo);
# example      my $Class = LoadClassByAlias('LineItemPaymentPayPalPlus');
#               my $LineItemPaymentPayPalPlus = $Class->insertObject($hInfo);
#----------------------------------------------------------------------------------------
# description  Insert this info as object, afterwards the hook 'OBJ_InsertLineItemPaymentPayPalPlus' is triggered.
#----------------------------------------------------------------------------------------
# input        $Package | class package | string
# input        $hInfo | attributes of new object | ref.hash
# return       $LineItemPaymentPayPalPlus | new object | object
# hook         OBJ_InsertLineItemPaymentPayPalPlus | hook parameter keys :
#               <ul>
#                 <li>Object        - this object          - object
#                 <li>LineItemPaymentPayPalPlusID - line item payment id - int
#               </ul>
#========================================================================================
sub insert {
    my ($Package, $hInfo) = @_;

    my $self = $Package->SUPER::insert($hInfo);

    TriggerHook('OBJ_InsertLineItemPaymentPayPalPlus', {
        'Object' => $self,
        'LineItemPaymentPayPalPlusID' => $self->id()
    });

    return $self;
}

#========================================================================================
# function     delete
# state        private
#----------------------------------------------------------------------------------------
# syntax       $LineItemPaymentPayPalPlus->delete;
#----------------------------------------------------------------------------------------
# description  Deletes this object, therefore the hook 'OBJ_DeleteLineItemPaymentPayPalPlus' is triggered.
#----------------------------------------------------------------------------------------
# hook         OBJ_DeleteLineItemPaymentPayPalPlus | hook parameter keys :
#               <ul>
#                 <li>Object        - this object          - object
#                 <li>LineItemPaymentPayPalPlusID - line item payment id - int
#               </ul>
#========================================================================================
sub delete {
    my $self = shift;

    TriggerHook('OBJ_DeleteLineItemPaymentPayPalPlus', {
        'Object' => $self,
        'LineItemPaymentPayPalPlusID' => $self->id()
    });

    $self->SUPER::delete();
    return;
}

#========================================================================================
# function     set
# state        private
#----------------------------------------------------------------------------------------
# syntax       $LineItemPaymentPayPalPlus->set($hValues, $LanguageID);
#----------------------------------------------------------------------------------------
# description  This function triggers hooks 'OBJ_BeforeUpdateLineItemPaymentPayPalPlus'
#               and 'OBJ_AfterUpdateLineItemPaymentPayPalPlus'.
#----------------------------------------------------------------------------------------
# input        $hValues | attribute name => value hash | ref.hash
# input        $LanguageID | (optional; required for localized attributes) language id | int
#----------------------------------------------------------------------------------------
# hook         OBJ_BeforeUpdateLineItemPaymentPayPalPlus | hook parameter keys :
#               <ul>
#                 <li>Object        - this object          - object
#                 <li>LineItemPaymentPayPalPlusID - line item payment id - int
#                 <li>Values        - new values for object - ref.hash
#                 <li>LanguageID    - values of this language will be updated - int
#               </ul>
# hook         OBJ_AfterUpdateLineItemPaymentPayPalPlus | hook parameter keys :
#               <ul>
#                 <li>Object        - this object          - object
#                 <li>LineItemPaymentPayPalPlusID - line item payment id - int
#                 <li>Values        - updated values       - ref.hash
#                 <li>LanguageID    - values updated of this language - int
#               </ul>
#========================================================================================
sub set {
    my $self = shift;
    my ($hValues, $LanguageID) = @_;

    TriggerHook('OBJ_BeforeUpdateLineItemPaymentPayPalPlus', {
        'Object' => $self,
        'Values' => $hValues,
        'LineItemPaymentPayPalPlusID' => $self->id(),
        'LanguageID' => $LanguageID
    });

    $self->SUPER::set($hValues, $LanguageID);

    TriggerHook('OBJ_AfterUpdateLineItemPaymentPayPalPlus', {
        'Object' => $self,
        'Values' => $hValues,
        'LineItemPaymentPayPalPlusID' => $self->id(),
        'LanguageID' => $LanguageID
    });

    return;
}

#========================================================================================
# function     getAdditionalData
# state        public
#----------------------------------------------------------------------------------------
# syntax       $LineItemPaymentPayPalPlus->getAdditionalData( );
#----------------------------------------------------------------------------------------
# description  it provides additional payment data, included into Order Rest API calls.
#----------------------------------------------------------------------------------------
# return       $FormattedData | formatted payment data string | string
#========================================================================================
sub getAdditionalData {
    my $self = shift;

    my $hInvoiceData = $self->get( [ qw( InvoiceReferenceNumber InvoiceBankName InvoiceAccountHolderName InvoiceIBAN
        InvoiceBIC InvoicePaymentDueDate InvoiceAmount InvoiceCurrency ) ]
    );
    my $DateFormatter = DE_EPAGES::XML::API::DateTimeFormatXML->new();
    my $FormattedDueDate = isValid($hInvoiceData->{'InvoicePaymentDueDate'}) ?
            $DateFormatter->format_datetime($hInvoiceData->{'InvoicePaymentDueDate'}, 'UTC') :
            $hInvoiceData->{'InvoicePaymentDueDate'};

    return {
        'InvoiceReferenceNumber' => $hInvoiceData->{'InvoiceReferenceNumber'},
        'InvoiceBankName' => $hInvoiceData->{'InvoiceBankName'},
        'InvoiceAccountHolderName' => $hInvoiceData->{'InvoiceAccountHolderName'},
        'InvoiceIBAN' => $hInvoiceData->{'InvoiceIBAN'},
        'InvoiceBIC' => $hInvoiceData->{'InvoiceBIC'},
        'InvoicePaymentDueDate' => $FormattedDueDate,
        'InvoiceAmount' => $hInvoiceData->{'InvoiceAmount'},
        'InvoiceCurrency' => $hInvoiceData->{'InvoiceCurrency'}
    };

}

1;