#========================================================================================
# package      DE_EPAGES::Presentation::API::SpamprotectionConfig
# state        public
# description  Interface to the Spamprotection.conf file.
#               This configuration file is case sensitive.
#========================================================================================
package DE_EPAGES::Presentation::API::SpamprotectionConfig;
use base qw (Exporter);
use strict;

our @EXPORT_OK  = qw (
    SpamprotectionConfig
);

use DE_EPAGES::Core::API::File qw (GetCachedFile);
use DE_EPAGES::Core::API::IniConfig;
use DE_EPAGES::Core::API::Log qw (GetLog);

my $CONFIG_FILENAME = "$ENV{'EPAGES_CONFIG'}/spamprotection.conf";

#========================================================================================
# function     SpamprotectionConfig
# state        public
#----------------------------------------------------------------------------------------
# syntax       $IniConfig = SpamprotectionConfig();
# example      my $Min = SpamprotectionConfig()->get('FormSubmitTimeframe_Forum', 'BlogPost_AddReply_Min')
#----------------------------------------------------------------------------------------
# description  Returns an  IniConfig object of the spamprotection.conf file.
#               see <package DE_EPAGES::Core::API::IniConfig>
#----------------------------------------------------------------------------------------
# return       $IniConfig | config object | object
#========================================================================================
sub SpamprotectionConfig() {
    return GetCachedFile( $CONFIG_FILENAME, sub {
        my ($FileName) = @_;
        GetLog->debug( "Loading config file $FileName" );
        return DE_EPAGES::Core::API::IniConfig->new(
            FileName => $FileName,
            Create => 1,
            CaseSensitive => 1,
        );
    });
}

1;
