#========================================================================================
# package      DE_EPAGES::Presentation::t::TimeframeCheck
# state        public
#----------------------------------------------------------------------------------------
# description  Tests for timeframe.
#========================================================================================
package DE_EPAGES::Presentation::t::TimeframeCheck;
use base DE_EPAGES::Core::API::Test;

use strict;
use warnings;
use Test::More;
use utf8;

use DE_EPAGES::Presentation::Servlet::Permission qw( _timeframeCheck );

plan tests => 14;

sub test {

    #Object initialization
    local *_timeframeCheck      = \&DE_EPAGES::Presentation::Servlet::Permission::_timeframeCheck; ## no critic qw(ProtectPrivateVars)

    #Basic checks
    my $TimeUntilSubmit = 20;
    is(_timeframeCheck($TimeUntilSubmit, 10, 30), 1, 'Submit within boundaries');
    is(_timeframeCheck($TimeUntilSubmit, 30, 40), 0, 'Submit out of lower boundary');
    is(_timeframeCheck($TimeUntilSubmit, 10, 15), 0, 'Submit out of upper boundary');

    #Only one boundary set
    is(_timeframeCheck($TimeUntilSubmit, 10, undef), 1, 'Within boundary, Max undefined');
    is(_timeframeCheck($TimeUntilSubmit, 30, undef), 0, 'Out of boundary, Max undefined');
    is(_timeframeCheck($TimeUntilSubmit, undef, 30), 1, 'Within boundary, Min undefined');
    is(_timeframeCheck($TimeUntilSubmit, undef, 15), 0, 'Out of boundary, Min undefined');

    #One boundary is 0
    is(_timeframeCheck($TimeUntilSubmit, 10, 0), 1, 'Within boundary, Max unchecked');
    is(_timeframeCheck($TimeUntilSubmit, 30, 0), 0, 'Out of boundary, Max unchecked');
    is(_timeframeCheck($TimeUntilSubmit, 0, 30), 1, 'Within boundary, Min unchecked');
    is(_timeframeCheck($TimeUntilSubmit, 0, 15), 0, 'Out of boundary, Min unchecked');

    #Bad config tests
    is(_timeframeCheck($TimeUntilSubmit, 30, 10), 1, 'Allow submit despite bad configuration - swapped boundaries');
    is(_timeframeCheck($TimeUntilSubmit, undef, undef), 1, 'Allow submit despite bad configuration - no boundaries');

    #Bad values gained from decrypting malformed data
    is(_timeframeCheck('I am not a number', 10, 30), 0, 'String input');

    done_testing();
}
__PACKAGE__->runScript();

1;
