#==============================================================================
# package      DE_EPAGES::Product::UI::ProductTypeFolder
# base         DE_EPAGES::Presentation::UI::Object
# state        private
#==============================================================================
package DE_EPAGES::Product::UI::ProductTypeFolder;
use base DE_EPAGES::Presentation::UI::Object;

use strict;
use DE_EPAGES::Object::API::Factory          qw ( LoadClassByAlias ExistsObject );
use DE_EPAGES::Core::API::Error              qw ( Error ExistsError GetError );
use DE_EPAGES::Core::API::Warning            qw ( Warning );

#==============================================================================
# Event handlers
#==============================================================================

sub NewProductType {
    my $self = shift;
    my ($Servlet) = @_;

    return unless defined $Servlet->params('Alias');

    my $Folder = $Servlet->object;
    my $Shop = $Folder->parent;
    my $BaseClass = $Shop->get('ProductClass');
    my $Class = LoadClassByAlias('ProductType');

    eval {
        $self->NewObject( $Servlet, $Folder, $Class, {
            BaseClass => $BaseClass,
        } );
    };
    if (ExistsError()) {
        my $Error = GetError();
        if ($Error->code  eq 'FeatureLimitExceeded'){
            $Servlet->vars('FeatureMaxValueReached', $Error->vars);
            Warning($Error);
        } else {
            Error($Error);
        }
    }
    return;
}

sub UnityNewProductType {
    my $self = shift;
    my ($Servlet) = @_;
    my $Name = $Servlet->params('Name');

    $Servlet->form->executeFormError({
        'Form'   => 'Save',
        'Reason' => 'NAME_NOT_VALID',
        'Name'   => 'Name',
        'Value'  => '',
    }) unless defined $Name and $Name =~ /\S/;

    my $Folder = $Servlet->object;
    my $Shop = $Folder->getSite();
    my $BaseClass = $Shop->get('ProductClass');
    my $Class = LoadClassByAlias('ProductType');

    my $NewProductType;
    eval {
        $NewProductType = $self->NewObject( $Servlet, $Folder, $Class, {
            BaseClass => $BaseClass,
        } );
    };
    if (ExistsError()) {
        my $Error = GetError();
        if ($Error->code  eq 'FeatureLimitExceeded'){
            $Servlet->vars('FeatureMaxValueReached', $Error->vars);
            Warning($Error);
        } else {
            Error($Error);
        }
    } else {
        $Servlet->vars('ViewAction', 'UnityMBO-ViewGeneral');
        my $ObjID = $NewProductType -> get('ObjectID');
        $Servlet->vars('ObjectID', $ObjID);
        $Servlet->vars('NewlyCreated', 1);
    }
    return;
}

sub View {
    my $self = shift;
    my ($Servlet) = @_;

    my %CountProductsByType = ();
    my $MasterObject = $Servlet->object;
    my @ExistingClass = @{$MasterObject->children};
    my $ProductDAL = LoadClassByAlias('Product')->dalObject;
    $CountProductsByType{$_->id} = scalar @{$ProductDAL->get('ByClassID', [$_->id])} foreach @ExistingClass;

    my @tleHashes = map { $_->tleHash } @ExistingClass;
    #extend tleHash with NumberOfProducts information
    $_->{'NumberOfProducts'} = $CountProductsByType{$_->{'ID'}} foreach @tleHashes;
    $Servlet->vars('OurProducts', \@tleHashes);
}

sub DeleteListedObjects {
    my $self = shift;
    my ($Servlet) = @_;

    # nothing to do
    return if ! $Servlet->params('ListObjectID');

    my $MasterObject = $Servlet->object;
    my $Form = $Servlet->form;
    my $hValues = $Form->form($MasterObject, 'ListedObjects');
    my $BaseProductTypeID = $MasterObject->getSite->get('ProductClass')->id;
    my @ExistingClassIDs = grep { ExistsObject($_) }
                      # do not allow the deletion of the base product type (UNITY-6249)
                      grep { $_ != $BaseProductTypeID }
                      map { $_->{'ListObjectID'} }
                      @{$hValues->{'ListObjectIDs'}};

    my %CountProductsByType = ();
    my $ProductDAL = LoadClassByAlias('Product')->dalObject;
    $CountProductsByType{$_} = scalar @{$ProductDAL->get('ByClassID', [$_])} foreach @ExistingClassIDs;

    my $HaveProducts = 0;
    $HaveProducts += $_ foreach values %CountProductsByType;

    # delete only if accepted if confirmation is used and if there are no products
    if ($HaveProducts or $Servlet->user->get('DeleteConfirmation') and not $Servlet->params('ACCEPT')) {
        my $Shop = $MasterObject->getSite();
        my @tleHashes = map { $Shop->loadObject($_, 'ProductType')->tleHash } @ExistingClassIDs;
        # extend tleHash with NumberOfProducts information
        $_->{'NumberOfProducts'} = $CountProductsByType{$_->{'ID'}} foreach @tleHashes;

        $Servlet->vars('DeleteObjects', \@tleHashes);
        $Servlet->vars('HaveProducts', $HaveProducts);
        $Servlet->vars('DELETE',1);
        return;
    } else {
        # else reset delete
        $Servlet->vars('DELETE',0);
    }

    # delete objects in list
    $self->SUPER::DeleteListedObjects($Servlet);

    return;
}

1;
